==> zio-aws-lambda_2.12-5.17.239.1-sources.jar: zio/aws/lambda/model/FunctionUrlConfig.scala <==
package zio.aws.lambda.model
import zio.aws.lambda.model.primitives.{Timestamp, FunctionArn, FunctionUrl}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class FunctionUrlConfig(
    functionUrl: FunctionUrl,
    functionArn: FunctionArn,
    creationTime: Timestamp,
    lastModifiedTime: Timestamp,
    cors: Optional[zio.aws.lambda.model.Cors] = Optional.Absent,
    authType: zio.aws.lambda.model.FunctionUrlAuthType
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.FunctionUrlConfig = {
    import FunctionUrlConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.FunctionUrlConfig
      .builder()
      .functionUrl(FunctionUrl.unwrap(functionUrl): java.lang.String)
      .functionArn(FunctionArn.unwrap(functionArn): java.lang.String)
      .creationTime(Timestamp.unwrap(creationTime): java.lang.String)
      .lastModifiedTime(Timestamp.unwrap(lastModifiedTime): java.lang.String)
      .optionallyWith(cors.map(value => value.buildAwsValue()))(_.cors)
      .authType(authType.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.lambda.model.FunctionUrlConfig.ReadOnly =
    zio.aws.lambda.model.FunctionUrlConfig.wrap(buildAwsValue())
}
object FunctionUrlConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.FunctionUrlConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lambda.model.FunctionUrlConfig =
      zio.aws.lambda.model.FunctionUrlConfig(
        functionUrl,
        functionArn,
        creationTime,
        lastModifiedTime,
        cors.map(value => value.asEditable),
        authType
      )
    def functionUrl: FunctionUrl
    def functionArn: FunctionArn
    def creationTime: Timestamp
    def lastModifiedTime: Timestamp
    def cors: Optional[zio.aws.lambda.model.Cors.ReadOnly]
    def authType: zio.aws.lambda.model.FunctionUrlAuthType
    def getFunctionUrl: ZIO[Any, Nothing, FunctionUrl] =
      ZIO.succeed(functionUrl)
    def getFunctionArn: ZIO[Any, Nothing, FunctionArn] =
      ZIO.succeed(functionArn)
    def getCreationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationTime)
    def getLastModifiedTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(lastModifiedTime)
    def getCors: ZIO[Any, AwsError, zio.aws.lambda.model.Cors.ReadOnly] =
      AwsError.unwrapOptionField("cors", cors)
    def getAuthType
        : ZIO[Any, Nothing, zio.aws.lambda.model.FunctionUrlAuthType] =
      ZIO.succeed(authType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.FunctionUrlConfig
  ) extends zio.aws.lambda.model.FunctionUrlConfig.ReadOnly {
    override val functionUrl: FunctionUrl =
      zio.aws.lambda.model.primitives.FunctionUrl(impl.functionUrl())
    override val functionArn: FunctionArn =
      zio.aws.lambda.model.primitives.FunctionArn(impl.functionArn())
    override val creationTime: Timestamp =
      zio.aws.lambda.model.primitives.Timestamp(impl.creationTime())
    override val lastModifiedTime: Timestamp =
      zio.aws.lambda.model.primitives.Timestamp(impl.lastModifiedTime())
    override val cors: Optional[zio.aws.lambda.model.Cors.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cors())
        .map(value => zio.aws.lambda.model.Cors.wrap(value))
    override val authType: zio.aws.lambda.model.FunctionUrlAuthType =
      zio.aws.lambda.model.FunctionUrlAuthType.wrap(impl.authType())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.FunctionUrlConfig
  ): zio.aws.lambda.model.FunctionUrlConfig.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lambda_2.12-7.21.15.8-sources.jar: zio/aws/lambda/model/FunctionUrlConfig.scala <==
package zio.aws.lambda.model
import zio.aws.lambda.model.primitives.{Timestamp, FunctionArn, FunctionUrl}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class FunctionUrlConfig(
    functionUrl: FunctionUrl,
    functionArn: FunctionArn,
    creationTime: Timestamp,
    lastModifiedTime: Timestamp,
    cors: Optional[zio.aws.lambda.model.Cors] = Optional.Absent,
    authType: zio.aws.lambda.model.FunctionUrlAuthType,
    invokeMode: Optional[zio.aws.lambda.model.InvokeMode] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.FunctionUrlConfig = {
    import FunctionUrlConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.FunctionUrlConfig
      .builder()
      .functionUrl(FunctionUrl.unwrap(functionUrl): java.lang.String)
      .functionArn(FunctionArn.unwrap(functionArn): java.lang.String)
      .creationTime(Timestamp.unwrap(creationTime): java.lang.String)
      .lastModifiedTime(Timestamp.unwrap(lastModifiedTime): java.lang.String)
      .optionallyWith(cors.map(value => value.buildAwsValue()))(_.cors)
      .authType(authType.unwrap)
      .optionallyWith(invokeMode.map(value => value.unwrap))(_.invokeMode)
      .build()
  }
  def asReadOnly: zio.aws.lambda.model.FunctionUrlConfig.ReadOnly =
    zio.aws.lambda.model.FunctionUrlConfig.wrap(buildAwsValue())
}
object FunctionUrlConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.FunctionUrlConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lambda.model.FunctionUrlConfig =
      zio.aws.lambda.model.FunctionUrlConfig(
        functionUrl,
        functionArn,
        creationTime,
        lastModifiedTime,
        cors.map(value => value.asEditable),
        authType,
        invokeMode.map(value => value)
      )
    def functionUrl: FunctionUrl
    def functionArn: FunctionArn
    def creationTime: Timestamp
    def lastModifiedTime: Timestamp
    def cors: Optional[zio.aws.lambda.model.Cors.ReadOnly]
    def authType: zio.aws.lambda.model.FunctionUrlAuthType
    def invokeMode: Optional[zio.aws.lambda.model.InvokeMode]
    def getFunctionUrl: ZIO[Any, Nothing, FunctionUrl] =
      ZIO.succeed(functionUrl)
    def getFunctionArn: ZIO[Any, Nothing, FunctionArn] =
      ZIO.succeed(functionArn)
    def getCreationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationTime)
    def getLastModifiedTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(lastModifiedTime)
    def getCors: ZIO[Any, AwsError, zio.aws.lambda.model.Cors.ReadOnly] =
      AwsError.unwrapOptionField("cors", cors)
    def getAuthType
        : ZIO[Any, Nothing, zio.aws.lambda.model.FunctionUrlAuthType] =
      ZIO.succeed(authType)
    def getInvokeMode: ZIO[Any, AwsError, zio.aws.lambda.model.InvokeMode] =
      AwsError.unwrapOptionField("invokeMode", invokeMode)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.FunctionUrlConfig
  ) extends zio.aws.lambda.model.FunctionUrlConfig.ReadOnly {
    override val functionUrl: FunctionUrl =
      zio.aws.lambda.model.primitives.FunctionUrl(impl.functionUrl())
    override val functionArn: FunctionArn =
      zio.aws.lambda.model.primitives.FunctionArn(impl.functionArn())
    override val creationTime: Timestamp =
      zio.aws.lambda.model.primitives.Timestamp(impl.creationTime())
    override val lastModifiedTime: Timestamp =
      zio.aws.lambda.model.primitives.Timestamp(impl.lastModifiedTime())
    override val cors: Optional[zio.aws.lambda.model.Cors.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cors())
        .map(value => zio.aws.lambda.model.Cors.wrap(value))
    override val authType: zio.aws.lambda.model.FunctionUrlAuthType =
      zio.aws.lambda.model.FunctionUrlAuthType.wrap(impl.authType())
    override val invokeMode: Optional[zio.aws.lambda.model.InvokeMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.invokeMode())
        .map(value => zio.aws.lambda.model.InvokeMode.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.FunctionUrlConfig
  ): zio.aws.lambda.model.FunctionUrlConfig.ReadOnly = new Wrapper(impl)
}
